pub struct Block<K: ColumnType = Simple> { /* private fields */ }
Represents Clickhouse Block

Implementations

source

impl Block

source

pub fn new() -> Self

Constructs a new, empty Block.

source

pub fn with_capacity(capacity: usize) -> Self

Constructs a new, empty Block with the specified capacity.

source

impl<K: ColumnType> Block<K>

source

pub fn row_count(&self) -> usize

Return the number of rows in the current block.

source

pub fn column_count(&self) -> usize

Return the number of columns in the current block.

source

pub fn columns(&self) -> &[Column<K>]

This method returns a slice of columns.

source

pub fn get<'a, T, I>(&'a self, row: usize, col: I) -> Result<T>where T: FromSql<'a>, I: ColumnIdx + Copy,

Get the value of a particular cell of the block.

source

pub fn add_column<S>(self, name: &str, values: S) -> Selfwhere S: ColumnFrom,

Add new column into this block

source

pub fn column<S>(self, name: &str, values: S) -> Selfwhere S: ColumnFrom,

Add new column into this block

source

pub fn is_empty(&self) -> bool

Returns true if the block contains no elements.

source

pub fn rows(&self) -> Rows<'_, K>

This method returns a iterator of rows.

source

pub fn push<B: RowBuilder>(&mut self, row: B) -> Result<()>

This method is a convenient way to pass row into a block.

source

pub fn get_column<I>(&self, col: I) -> Result<&Column<K>>where I: ColumnIdx + Copy,

This method finds a column by identifier.