pub struct Row<'a, K: ColumnType> { /* private fields */ }
Get the value of a particular cell of the row.
Return the number of cells in the current row.
Returns true if the row contains no cells.
Get the name of a particular cell of the row.
Get the type of a particular cell of the row.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer.
Read more
Mutably dereferences the given pointer.
Read more
Drops the object pointed to by the given pointer.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.